<?php

/**
 * @package wp fancy title
 * @version 1.1
 */
class WftSettingsPage
{
    /**
     * Holds the values to be used in the fields callbacks
     */
    private $options;

    /**
     * Start up
     */
    public function __construct()
    {
        add_action('admin_menu', array($this, 'add_plugin_page'));
        add_action('admin_init', array($this, 'page_init'));
    }

    /**
     * Add options page
     */
    public function add_plugin_page()
    {
        // This page will be under "Settings"
        add_options_page(
            esc_html__('Settings Admin', 'wtf'),
            esc_html__('WTF Settings', 'wtp'),
            'manage_options',
            'wft-setting-admin',
            array($this, 'wtf_create_admin_page')
        );
    }

    /**
     * Options page callback
     */
    public function wtf_create_admin_page()
    {
        // Set class property
        $this->options = get_option('wft_option_name');
?>
        <div class="wrap">
            <h2><?php esc_html__('Wft Settings', 'wft'); ?></h2>
            <form method="post" action="options.php">
                <?php
                // This prints out all hidden setting fields
                settings_fields('wft_option_group');
                do_settings_sections('wft-setting-admin');
                submit_button();
                ?>
            </form>
        </div>
<?php
    }

    /**
     * Register and add settings
     */
    public function page_init()
    {
        register_setting(
            'wft_option_group', // Option group
            'wft_option_name', // Option name
            array($this, 'sanitize') // Sanitize
        );

        add_settings_section(
            'setting_section_id', // ID
            esc_html__('Wft Custom Settings', 'wtf'), // Title
            array($this, 'print_section_info'), // Callback
            'wft-setting-admin' // Page
        );
        add_settings_field(
            'miss_title_on', // ID
            esc_html__('Miss you title on', 'wtf'), // Title 
            array($this, 'miss_title_on_callback'), // Callback
            'wft-setting-admin', // Page
            'setting_section_id' // Section           
        );
        add_settings_field(
            'miss_u_title', // ID
            esc_html__('Miss you title', 'wtf'), // Title 
            array($this, 'miss_yuo_callback'), // Callback
            'wft-setting-admin', // Page
            'setting_section_id' // Section           
        );

        add_settings_field(
            'title_blink',
            esc_html__('Main title alt on/off', 'wtf'), // Title 
            array($this, 'title_blink_callback'),
            'wft-setting-admin',
            'setting_section_id'
        );
        add_settings_field(
            'blink_alt_text',
            esc_html__('Main title alt Text', 'wtf'), // Title 
            array($this, 'blink_alt_text_callback'),
            'wft-setting-admin',
            'setting_section_id'
        );
        add_settings_field(
            'miss_blink_alt_text',
            esc_html__('Miss you title alt Text', 'wtf'), // Title 
            array($this, 'miss_blink_alt_text_callback'),
            'wft-setting-admin',
            'setting_section_id'
        );
        add_settings_field(
            'miss_title_marquee',
            esc_html__('Title scroll', 'wtf'), // Title 
            array($this, 'miss_title_marquee_callback'),
            'wft-setting-admin',
            'setting_section_id'
        );
    }

    /**
     * Sanitize each setting field as needed
     *
     * @param array $input Contains all settings fields as array keys
     */
    public function sanitize($input)
    {
        $new_input = array();
        if (isset($input['miss_u_title']))
            $new_input['miss_u_title'] = sanitize_text_field($input['miss_u_title']);

        if (isset($input['miss_title_on']))
            $new_input['miss_title_on'] = sanitize_text_field($input['miss_title_on']);

        if (isset($input['title_blink']))
            $new_input['title_blink'] = sanitize_text_field($input['title_blink']);

        if (isset($input['blink_alt_text']))
            $new_input['blink_alt_text'] = sanitize_text_field($input['blink_alt_text']);

        if (isset($input['miss_blink_alt_text']))
            $new_input['miss_blink_alt_text'] = sanitize_text_field($input['miss_blink_alt_text']);
        if (isset($input['miss_title_marquee']))
            $new_input['miss_title_marquee'] = sanitize_text_field($input['miss_title_marquee']);


        return $new_input;
    }

    /** 
     * Print the Section text
     */
    public function print_section_info()
    {
        print esc_html__('Configure your settings below:', 'wft');
    }

    /** 
     * Get the settings option array and print one of its values
     */
    public function miss_title_on_callback()
    {
        $checked = !empty($this->options['miss_title_on']) ? esc_attr($this->options['miss_title_on']) : '';

        echo '<input type="checkbox" id="miss_title_on" name="wft_option_name[miss_title_on]" value="true" ' . checked('true', $checked, false) . '/>';
    }
    public function miss_yuo_callback()
    {
        printf(
            '<input type="text" id="miss_u_title" name="wft_option_name[miss_u_title]" value="%s" />',
            !empty($this->options['miss_u_title']) ? esc_attr($this->options['miss_u_title']) : ''
        );
    }

    /** 
     * Get the settings option array and print one of its values
     */
    public function title_blink_callback()
    {
        $checked = !empty($this->options['title_blink']) ? esc_attr($this->options['title_blink']) : '';
        echo '<fieldset><label><input type="radio" id="title_blink" name="wft_option_name[title_blink]" value="0" ' . checked(false, $checked, false) . '/> ' . esc_html__('Title alt none', 'wtf') . '</label><br>';
        echo '<label><input type="radio" id="title_blink" name="wft_option_name[title_blink]" value="1" ' . checked('1', $checked, false) . '/> ' . esc_html__('Main title alt', 'wtf') . '</label><br>';
        echo '<label><input type="radio" id="title_blink" name="wft_option_name[title_blink]" value="2" ' . checked('2', $checked, false) . '/> ' . esc_html__('Miss you title alt', 'wtf') . '</label><br>';
        echo '<label><input type="radio" id="title_blink" name="wft_option_name[title_blink]" value="3" ' . checked('3', $checked, false) . '/> ' . esc_html__('Both title alt', 'wtf') . '</label></fieldset>';
    }
    public function blink_alt_text_callback()
    {
        printf(
            '<input type="text" id="blink_alt_text" name="wft_option_name[blink_alt_text]" value="%s" />',
            !empty($this->options['blink_alt_text']) ? esc_attr($this->options['blink_alt_text']) : ''
        );
    }
    public function miss_blink_alt_text_callback()
    {
        printf(
            '<input type="text" id="miss_blink_alt_text" name="wft_option_name[miss_blink_alt_text]" value="%s" />',
            !empty($this->options['miss_blink_alt_text']) ? esc_attr($this->options['miss_blink_alt_text']) : ''
        );
    }
    public function miss_title_marquee_callback()
    {
        $checked = !empty($this->options['miss_title_marquee']) ? esc_attr($this->options['miss_title_marquee']) : '';
        echo '<fieldset><label><input type="radio" id="miss_title_marquee" name="wft_option_name[miss_title_marquee]" value="0" ' . checked(false, $checked, false) . '/> ' . esc_html__('Scroll none', 'wtf') . '</label><br>';
        echo '<label><input type="radio" id="miss_title_marquee" name="wft_option_name[miss_title_marquee]" value="1" ' . checked('1', $checked, false) . '/> ' . esc_html__('Scroll main title', 'wtf') . '</label><br>';
        echo '<label><input type="radio" id="miss_title_marquee" name="wft_option_name[miss_title_marquee]" value="2" ' . checked('2', $checked, false) . '/> ' . esc_html__('Scroll miss you title', 'wtf') . '</label><br>';
        echo '<label><input type="radio" id="miss_title_marquee" name="wft_option_name[miss_title_marquee]" value="3" ' . checked('3', $checked, false) . '/> ' . esc_html__('Scroll both', 'wtf') . '</label></fieldset>';
    }
}

if (is_admin())
    $wft_settings_page = new WftSettingsPage();
